pub struct EndLlmHandleParams<'a> {
pub handle: &'a LlmHandle,
pub data: Option<Json>,
pub metadata: Option<Json>,
pub annotated_response: Option<Arc<AnnotatedLlmResponse>>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for NemoFlowContextState::build_llm_end_event.
Fields
handle: &'a LlmHandleLLM handle to serialize into the emitted end event.
data: Option<Json>Optional data payload merged over the handle data.
metadata: Option<Json>Optional metadata payload merged over the handle metadata.
annotated_response: Option<Arc<AnnotatedLlmResponse>>Optional normalized response annotation produced by a response codec.
timestamp: Option<DateTime<Utc>>Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.
Implementations
Sourceimpl<'a> EndLlmHandleParams<'a>
impl<'a> EndLlmHandleParams<'a>
Sourcepub fn builder() -> EndLlmHandleParamsBuilder<'a, ((), (), (), (), ())>
pub fn builder() -> EndLlmHandleParamsBuilder<'a, ((), (), (), (), ())>
Create a builder for building EndLlmHandleParams.
On the builder, call .handle(...), .data(...)(optional), .metadata(...)(optional), .annotated_response(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of EndLlmHandleParams.