capture_thread_scope_stack

Function capture_thread_scope_stack 

pub fn capture_thread_scope_stack() -> ThreadScopeStackBinding
Capture the current thread-local scope stack binding.

This is intended for foreign runtimes that temporarily bind a scope stack to an OS thread and need to restore the exact previous state before releasing that thread back to their scheduler.