pub fn task_scope_push(handle: ScopeHandle)Expand description
Push a scope handle onto the active stack.
Parameters
handle: Scope handle to push onto the current execution context’s stack.
pub fn task_scope_push(handle: ScopeHandle)Push a scope handle onto the active stack.
handle: Scope handle to push onto the current execution context’s stack.