pub struct EndToolHandleParams<'a> {
pub handle: &'a ToolHandle,
pub data: Option<Json>,
pub metadata: Option<Json>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for NemoFlowContextState::build_tool_end_event.
Fields
handle: &'a ToolHandleTool handle to serialize into the emitted end event.
data: Option<Json>Optional data payload merged over the handle data.
metadata: Option<Json>Optional metadata payload merged over the handle metadata.
timestamp: Option<DateTime<Utc>>Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.
Implementations
Sourceimpl<'a> EndToolHandleParams<'a>
impl<'a> EndToolHandleParams<'a>
Sourcepub fn builder() -> EndToolHandleParamsBuilder<'a, ((), (), (), ())>
pub fn builder() -> EndToolHandleParamsBuilder<'a, ((), (), (), ())>
Create a builder for building EndToolHandleParams.
On the builder, call .handle(...), .data(...)(optional), .metadata(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of EndToolHandleParams.