ToolCallEndParams

Struct ToolCallEndParams 

pub struct ToolCallEndParams<'a> {
    pub handle: &'a ToolHandle,
    pub result: Json,
    pub data: Option<Json>,
    pub metadata: Option<Json>,
    pub timestamp: Option<DateTime<Utc>>,
}
Builder parameters for tool_call_end.

Fields

handle: &'a ToolHandle

Tool handle to close.

result: Json

Raw tool result associated with the end event.

data: Option<Json>

Optional application payload retained for compatibility; ATOF data is the result.

metadata: Option<Json>

Optional JSON metadata recorded on the end event.

timestamp: Option<DateTime<Utc>>

Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.

Implementations

Source

impl<'a> ToolCallEndParams<'a>

pub fn builder() -> ToolCallEndParamsBuilder<'a, ((), (), (), (), ())>

Create a builder for building ToolCallEndParams. On the builder, call .handle(...), .result(...), .data(...)(optional), .metadata(...)(optional), .timestamp(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of ToolCallEndParams.