ToolCallParams

Struct ToolCallParams 

pub struct ToolCallParams<'a> {
    pub name: &'a str,
    pub args: Json,
    pub parent: Option<&'a ScopeHandle>,
    pub attributes: ToolAttributes,
    pub data: Option<Json>,
    pub metadata: Option<Json>,
    pub tool_call_id: Option<String>,
    pub timestamp: Option<DateTime<Utc>>,
}
Builder parameters for tool_call.

Fields

name: &'a str

Tool name recorded on the emitted lifecycle event.

args: Json

Raw tool arguments associated with the span.

parent: Option<&'a ScopeHandle>

Optional explicit parent scope.

attributes: ToolAttributes

Tool attribute bitflags applied to the span.

data: Option<Json>

Optional application payload stored on the handle but not emitted as Agent Trajectory Observability Format (ATOF) data.

metadata: Option<Json>

Optional JSON metadata recorded on the start event.

tool_call_id: Option<String>

Optional provider-specific correlation identifier.

timestamp: Option<DateTime<Utc>>

Optional timestamp captured as the handle start time and reused by the emitted start event. When omitted, the current UTC time is used.

Implementations

Source

impl<'a> ToolCallParams<'a>

pub fn builder() -> ToolCallParamsBuilder<'a, ((), (), (), (), (), (), (), ())>

Create a builder for building ToolCallParams. On the builder, call .name(...), .args(...), .parent(...)(optional), .attributes(...)(optional), .data(...)(optional), .metadata(...)(optional), .tool_call_id(...)(optional), .timestamp(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of ToolCallParams.