pub struct LlmCallEndParams<'a> {
pub handle: &'a LlmHandle,
pub response: Json,
pub data: Option<Json>,
pub metadata: Option<Json>,
pub annotated_response: Option<Arc<AnnotatedLlmResponse>>,
pub response_codec: Option<Arc<dyn LlmResponseCodec>>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for llm_call_end.
Fields
handle: &'a LlmHandleLLM handle to close.
response: JsonRaw provider response associated with the end event.
data: Option<Json>Optional application payload retained for compatibility; Agent Trajectory Observability Format (ATOF) data is the response.
metadata: Option<Json>Optional JSON metadata recorded on the end event.
annotated_response: Option<Arc<AnnotatedLlmResponse>>Optional normalized response annotation produced by a response codec.
response_codec: Option<Arc<dyn LlmResponseCodec>>Optional response codec used to produce an annotation from sanitized event data.
timestamp: Option<DateTime<Utc>>Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.
Implementations
Sourceimpl<'a> LlmCallEndParams<'a>
impl<'a> LlmCallEndParams<'a>
Sourcepub fn builder() -> LlmCallEndParamsBuilder<'a, ((), (), (), (), (), (), ())>
pub fn builder() -> LlmCallEndParamsBuilder<'a, ((), (), (), (), (), (), ())>
Create a builder for building LlmCallEndParams.
On the builder, call .handle(...), .response(...), .data(...)(optional), .metadata(...)(optional), .annotated_response(...)(optional), .response_codec(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of LlmCallEndParams.