pub struct LlmCallParams<'a> {
pub name: &'a str,
pub request: &'a LlmRequest,
pub parent: Option<&'a ScopeHandle>,
pub attributes: LlmAttributes,
pub data: Option<Json>,
pub metadata: Option<Json>,
pub model_name: Option<String>,
pub annotated_request: Option<Arc<AnnotatedLlmRequest>>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for llm_call.
Fields
name: &'a strLogical provider or model family name recorded on the span.
request: &'a LlmRequestRaw request associated with the span.
parent: Option<&'a ScopeHandle>Optional explicit parent scope.
attributes: LlmAttributesLLM attribute bitflags applied to the span.
data: Option<Json>Optional application payload stored on the handle but not emitted as Agent Trajectory Observability Format (ATOF) data.
metadata: Option<Json>Optional JSON metadata recorded on the start event.
model_name: Option<String>Optional normalized model name recorded separately from the request payload.
annotated_request: Option<Arc<AnnotatedLlmRequest>>Optional normalized request annotation produced by a codec.
timestamp: Option<DateTime<Utc>>Optional timestamp captured as the handle start time and reused by the emitted start event. When omitted, the current UTC time is used.
Implementations
Sourceimpl<'a> LlmCallParams<'a>
impl<'a> LlmCallParams<'a>
Sourcepub fn builder() -> LlmCallParamsBuilder<'a, ((), (), (), (), (), (), (), (), ())>
pub fn builder() -> LlmCallParamsBuilder<'a, ((), (), (), (), (), (), (), (), ())>
Create a builder for building LlmCallParams.
On the builder, call .name(...), .request(...), .parent(...)(optional), .attributes(...)(optional), .data(...)(optional), .metadata(...)(optional), .model_name(...)(optional), .annotated_request(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of LlmCallParams.