LlmStreamExecutionFn

Type Alias LlmStreamExecutionFn 

pub type LlmStreamExecutionFn = Arc<dyn Fn(&str, LlmRequest, LlmStreamExecutionNextFn) -> Pin<Box<dyn Future<Output = Result<LlmJsonStream>> + Send>> + Send + Sync>;
Wrap or replace streaming LLM execution.

A streaming execution intercept can observe or modify the request before invoking the continuation, and it can also replace the returned stream.

Aliased Type

pub struct LlmStreamExecutionFn { /* private fields */ }