pub type ToolInterceptFn = Box<dyn Fn(&str, Json) -> Result<Json> + Send + Sync>;Expand description
Rewrite tool arguments before execution.
Tool request intercepts run in priority order and can transform the JSON payload that is eventually passed into the tool execution callback.
Aliased Type
pub struct ToolInterceptFn(/* private fields */);